"""Module containing shims around Flake8 2.0 behaviour."""
import os.path

from flake8.formatting import base as formatter


class LegacyStyleGuide(object):
    """Public facing object that mimic's Flake8 2.0's StyleGuide."""

    def __init__(self, application):
        self._application = application
        self._file_checker_manager = application.file_checker_manager

    @property
    def options(self):
        """The parsed options.

        An instance of :class:`optparse.Values` containing parsed options.
        """
        return self._application.options

    @property
    def paths(self):
        """The extra arguments passed as paths."""
        return self._application.paths

    def check_files(self, paths=None):
        raise NotImplementedError('This should be easy')

    def excluded(self, filename, parent=None):
        return (self._file_checker_manager.is_path_excluded(filename) or
                (parent and
                    self._file_checker_manager.is_path_excluded(
                        os.path.join(parent, filename))))

    def init_report(self, reporter=None):
        if (reporter is not None and
                isinstance(reporter, formatter.BaseFormatter)):
            self._application.formatter = reporter
            self._application.guide = None
            # NOTE(sigmavirus24): This isn't the intended use of
            # Application#make_guide but it works pretty well.
            # Stop cringing... I know it's gross.
            self._application.make_guide()

    def input_file(self, filename, lines=None, expected=None, line_offset=0):
        raise NotImplementedError('This should be a pain')



# A Python file that can be used to start Pythonwin, instead of using
# pythonwin.exe
import os
import sys

import win32ui

import pywin.framework.intpyapp  # InteractivePythonApp()

assert pywin.framework.intpyapp  # not unused
# Pretend this script doesn't exist, or pythonwin tries to edit it
sys.argv[:] = sys.argv[1:] or [""]  # like PySys_SetArgv(Ex)
if sys.path[0] not in ("", ".", os.getcwd()):
    sys.path.insert(0, os.getcwd())
# And bootstrap the app.
app = win32ui.GetApp()
if not app.InitInstance():
    # Run when not already handled by DDE
    app.Run()
